@@ -1670,6 +1670,29 @@ class WebSapCommonFunctions:
 
         return check_result
 
+    def select_define_selection_options(self, input_title, input_index, option_name):
+        """This function is used to select define selection options
+
+        Args:
+            input_title(str): This is the title of input field
+            input_index(int): This is the index of input field
+            option_name(str): This is the option name to be selected
+        """
+        target_input_element = self.find_input_element_by_title(input_title, input_index)
+        for click_index in range(2):
+            self.click_or_input_by_element(target_input_element, 'click')
+            sleep(0.1)
+        self.wait_element_presence_by_css_selector("table[id$='mrss-cont-none-content' i]")
+        option_elements = self.browser.find_elements(By.CSS_SELECTOR, "table[id$='mrss-cont-none-content' i] tbody tr td:last-child div span span")
+        for option_element in option_elements:
+            if option_element.text.strip().upper() == str(option_name).upper():
+                for click_index in range(2):
+                    self.click_or_input_by_element(option_element, 'click')
+                    sleep(0.1)
+                break
+        self.wait_element_invisible_by_css_selector("table[id$='mrss-cont-none-content' i]")
+        sleep(2)
+
     def wait_file_upload_confirmation_dialog(self):
         """This function is used to wait file upload confirmation dialog window and click ok button
 
