@@ -19,6 +19,17 @@ UPLOAD_FILE_CHUNK_SIZE = 5 * 1024 * 1024
 
 class SharePointManager:
     def __init__(self, public_service_user_name, public_service_user_password, token_name, service_url, site_name, site_domain='bosch.sharepoint.com', verify_ssl=False):
+        """ This function is used to initialize SharePointManager class.
+
+        Args:
+            public_service_user_name(str): Public service username
+            public_service_user_password(str): Public service user password
+            token_name(str): Token name in public service
+            service_url(str): Public service URL
+            site_name(str): SharePoint site name. e.g. msteams_3167868-OIS2Teamchannel
+            site_domain(str): SharePoint site domain, default is 'bosch.sharepoint.com'
+            verify_ssl(bool|str): Whether to verify SSL certificate
+        """
         self.public_service_user_name = public_service_user_name
         self.public_service_user_password = public_service_user_password
         self.token_name = token_name
