@@ -150,7 +150,7 @@ def smb_traverse_remote_folder(username, password, server_name, share_name, remo
     smbclient.register_session(server_name, username=username, password=password, port=port, encrypt=True, connection_cache=connection_cache)
     try:
         for entry in smbclient.scandir(full_remote_folder_path, connection_cache=connection_cache):
-            if entry.name not in [".", ".."]:
+            if entry.name not in [".", ".."] and not entry.name.startswith("~$"):
                 stat_info = entry.stat()
                 traverse_result_list.append({
                     "name": entry.name,
